pub struct RevokeQuery {
pub client_id: Option<String>,
pub client_secret: Option<String>,
pub token: Option<String>,
pub token_type_hint: Option<String>,
pub _extra: HashMap<String, String>,
}Expand description
Query parameters for the OAuth 2.0 token revocation endpoint (RFC 7009).
The revocation endpoint allows clients to revoke access tokens or refresh tokens.
Fields
client_id: Option<String>client_secret: Option<String>token: Option<String>The token to be revoked (required).
token_type_hint: Option<String>Hint about the type of the token being revoked (optional). Valid values: “access_token” or “refresh_token”.
_extra: HashMap<String, String>Trait Implementations
Sourceimpl Debug for RevokeQuery
impl Debug for RevokeQuery
Sourceimpl<'de> Deserialize<'de> for RevokeQuery
impl<'de> Deserialize<'de> for RevokeQuery
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl OAuthValidate for RevokeQuery
impl OAuthValidate for RevokeQuery
type Output = RevokeParams
fn validate(&self) -> Result<Self::Output, ControllerError>